Type Definition json_ld::object::node::properties::BindingMut
source · pub type BindingMut<'a, T, B, M> = (Meta<&'a Id<T, B>, &'a mut M>, &'a mut Multiset<Stripped<Meta<Indexed<Object<T, B, M>, M>, M>>, DeterministicHasherBuilder>);Expand description
Tuple type representing a mutable reference to a binding in a node object, associating a property to some objects, with a mutable access to the objects.