[−][src]Struct json_ld::FsLoader
File-system loader.
This is a special JSON-LD document loader that can load document from the file system by attaching a directory to specific URLs.
Methods
impl FsLoader[src]