pub type BindingMut<'a, J, T> = (&'a Reference<T>, &'a mut Vec<Indexed<Object<J, T>>>);
Tuple type representing a mutable reference to a binding in a node object, associating a property to some objects, with a mutable access to the objects.