Type Definition json_ld::object::node::properties::BindingMut
source · [−]Expand description
Tuple type representing a mutable reference to a binding in a node object, associating a property to some objects, with a mutable access to the objects.